@@ -66,7 +66,7 @@ class Stem:
         self.Vine_rendered_symbol = None
 
         # Some stem subclasses will compute their vine end, but for a fixed geometry, we can do it right here
-        if self.Stem_type.Geometry == 'fixed':
+        if self.Stem_type.Geometry in {'fixed', 'free'}:
             # For a fixed geometry, the Vine end is a fixed distance from the Root End
             stem_len = self.Stem_type.Minimum_length
             # Compute the coordinates based on the stem direction using the rooted node face
@@ -80,7 +80,6 @@ class Stem:
             elif face == NodeFace.BOTTOM:
                 y = y - stem_len
             self.Vine_end = Position(x, y)
-        # TODO: consider Free geometry
 
     def render(self):
         """
@@ -120,13 +119,16 @@ class Stem:
                     name_y > diagram.Origin.y + diagram.Size.height:
                 self.logger.error(f"Stem text {self.Name.text.text} out of bounds on connector [{self.Connector.Name.text}]"
                                   f"\n\tConsider wrapping name across more lines of text or move it to the other side of the stem")
-                sys.exit()
+                sys.exit(1)
 
             layer.add_text_block(asset=self.Stem_type.Name + ' name', lower_left=Position(name_x, name_y),
                                   text=self.Name.text.text, align=align)
 
-        root_symbol_name = self.Stem_type.DecoratedStems[self.Semantic].Root_symbol
-        vine_symbol_name = self.Stem_type.DecoratedStems[self.Semantic].Vine_symbol
+        # TODO: Double check four lines below (especially for class diagram ternary connector root)
+        root_dec_stem = self.Stem_type.DecoratedStems.get(self.Semantic)
+        root_symbol_name = None if not root_dec_stem else root_dec_stem.Root_symbol
+        vine_dec_stem = self.Stem_type.DecoratedStems.get(self.Semantic)
+        vine_symbol_name = None if not vine_dec_stem else vine_dec_stem.Vine_symbol
 
         if root_symbol_name:
             self.Root_rendered_symbol = RenderedSymbol(
